@@ -1,10 +1,11 @@
 <?php
 namespace Concrete\Core\Board\Instance\Slot\Content\Populator;
 
-use Concrete\Core\Board\Instance\Slot\Content\ObjectInterface;
-use Concrete\Core\Board\Instance\Slot\Content\SummaryObjectCreatorTrait;
 use Concrete\Core\Board\Instance\Item\Data\DataInterface;
 use Concrete\Core\Board\Instance\Item\Data\PageData;
+use Concrete\Core\Board\Instance\Logger\Logger;
+use Concrete\Core\Board\Instance\Logger\LoggerInterface;
+use Concrete\Core\Board\Instance\Slot\Content\SummaryObjectCreatorTrait;
 use Concrete\Core\Page\Page;
 
 defined('C5_EXECUTE') or die("Access Denied.");
@@ -21,14 +22,16 @@ class PagePopulator extends AbstractPopulator
 
     /**
      * @param PageData $data
-     * @return ObjectInterface[]
+     * @param Logger|null $logger
+     * @return array
      */
-    public function createContentObjects(DataInterface $data): array
+    public function createContentObjects(DataInterface $data, LoggerInterface $logger): array
     {
         $page = Page::getByID($data->getPageID(), 'ACTIVE');
         if ($page && !$page->isError()) {
-            return $this->createSummaryContentObjects($page);
+            return $this->createSummaryContentObjects($page, $logger);
         }
+        return [];
     }
 
 }
